@@ -31,8 +31,10 @@ def Screen() -> turtle._Screen:
     else return the existing one."""
     return turtle.Screen()
 
+
 __is_screen_topmost = {}
 
+
 def move_screen_to_top(screen: turtle._Screen = None):
     '''
     Moves the given screen over all other windows and keeps it there. Defaults to the Screen() object.
@@ -152,6 +154,7 @@ def forward(step: int = 10):
     '''
     __SingletonTurtle().forward(step)
 
+
 def backward(step: int = 10):
     """Move the turtle backward by distance.
 
@@ -189,7 +192,8 @@ def step_up():
 
 def done():
     '''hides the turtle and waits until the resulting window is clicked'''
-    __SingletonTurtle().done()
+    __SingletonTurtle().hideturtle()
+    Screen().exitonclick()
 
 
 def home():
@@ -207,7 +211,7 @@ def home():
     __SingletonTurtle().home()
 
 
-def goto(x: int, y: int = None, draw: bool =True):
+def goto(x: int, y: int = None, draw: bool = True):
     """Move turtle to an absolute position.
 
     Aliases: setpos | goto:
@@ -239,14 +243,16 @@ def goto(x: int, y: int = None, draw: bool =True):
     (0.00,0.00)
     """
 
+    was_down = False
+
     if not draw:
         was_down = __SingletonTurtle().isdown()
-        __SingletonTurtle().up()
+        __SingletonTurtle().penup()
 
     __SingletonTurtle().goto(x, y=y)
 
     if not draw and was_down:
-        __SingletonTurtle().down()
+        __SingletonTurtle().pendown()
 
 
 def pos() -> turtle.Vec2D:
@@ -263,6 +269,20 @@ def pos() -> turtle.Vec2D:
     __SingletonTurtle().pos()
 
 
+def position() -> turtle.Vec2D:
+    """Return the turtle's current location (x,y), as a Vec2D-vector.
+
+    Aliases: pos | position
+
+    No arguments.
+
+    Example (for a Turtle instance named turtle):
+    >>> turtle.pos()
+    (0.00, 240.00)
+    """
+    __SingletonTurtle().pos()
+
+
 def setpos(x: int, y: int = None, draw=False):
     """Move turtle to an absolute position.
 
@@ -296,20 +316,6 @@ def setpos(x: int, y: int = None, draw=False):
     goto(x, y, draw=draw)
 
 
-def position() -> turtle.Vec2D:
-    """Return the turtle's current location (x,y), as a Vec2D-vector.
-
-    Aliases: pos | position
-
-    No arguments.
-
-    Example (for a Turtle instance named turtle):
-    >>> turtle.pos()
-    (0.00, 240.00)
-    """
-    __SingletonTurtle().pos()
-
-
 def heading() -> float:
     '''
     Return the turtle's current heading.
@@ -327,12 +333,12 @@ def setheading(to_angle) -> float:
     Set the orientation of the turtle to to_angle.
     Here are some common directions in degrees:
 
-    |    standard - mode:|          logo-mode:|
-    |:-------------------|:-------------------|
-    |    0 - east         |       0 - north   |
-    |    90 - north       |       90 - east   |
-    |    180 - west       |       180 - south |
-    |    270 - south      |       270 - west  |
+    |    standard - mode: |          logo-mode:|
+    |:--------------------|:-------------------|
+    |    0 - east         |       0 - north    |
+    |    90 - north       |       90 - east    |
+    |    180 - west       |       180 - south  |
+    |    270 - south      |       270 - west   |
 
     Example (for a Turtle instance named turtle):
     >>> turtle.setheading(90)
@@ -341,6 +347,38 @@ def setheading(to_angle) -> float:
     """
     return __SingletonTurtle().setheading(to_angle=to_angle)
 
+
+def fillcolor(*args):
+    """ Return or set the fillcolor.
+
+    Arguments:
+    Four input formats are allowed:
+        - fillcolor()
+        Return the current fillcolor as color specification string,
+        possibly in hex-number format (see example).
+        May be used as input to another color/pencolor/fillcolor call.
+        - fillcolor(colorstring)
+        s is a Tk color specification string, such as "red" or "yellow"
+        - fillcolor((r, g, b))
+        *a tuple* of r, g, and b, which represent, an RGB color,
+        and each of r, g, and b are in the range 0..colormode,
+        where colormode is either 1.0 or 255
+        - fillcolor(r, g, b)
+        r, g, and b represent an RGB color, and each of r, g, and b
+        are in the range 0..colormode
+
+    If turtleshape is a polygon, the interior of that polygon is drawn
+    with the newly set fillcolor.
+
+    Example (for a Turtle instance named turtle):
+    >>> turtle.fillcolor('violet')
+    >>> col = turtle.pencolor()
+    >>> turtle.fillcolor(col)
+    >>> turtle.fillcolor(0, .5, 0)
+    """
+    return __SingletonTurtle().fillcolor(*args)
+
+
 def color(*args):
     """Return or set the pencolor and fillcolor.
 
@@ -376,6 +414,7 @@ def color(*args):
     __SingletonTurtle().color(*args)
     return __SingletonTurtle().color()
 
+
 def colormode(cmode=None):
     """Return the colormode or set it to 1.0 or 255.
 
@@ -392,6 +431,7 @@ def colormode(cmode=None):
     """
     return Screen().colormode(cmode=cmode)
 
+
 def pencolor(*args):
     """ Return or set the pencolor.
 
@@ -423,6 +463,7 @@ def pencolor(*args):
     """
     return __SingletonTurtle().pencolor(*args)
 
+
 def home():
     """Move turtle to the origin - coordinates (0,0).
 
@@ -436,6 +477,7 @@ def home():
     """
     return __SingletonTurtle().home()
 
+
 def clear():
     """Delete all drawings and all turtles from the TurtleScreen.
 
@@ -451,6 +493,7 @@ def clear():
     """
     return __SingletonTurtle().clear()
 
+
 def distance(x, y=None):
     """Return the distance from the turtle to (x,y) in turtle step units.
 
@@ -474,7 +517,7 @@ def distance(x, y=None):
     77.0
     """
     return __SingletonTurtle().distance(x, y=y)
-    
+
 
 def dot():
     """Draw a dot with diameter size, using color.
@@ -492,6 +535,7 @@ def dot():
     """
     return __SingletonTurtle().dot()
 
+
 def pendown():
     """Pull the pen down -- drawing when moving.
 
@@ -504,6 +548,7 @@ def pendown():
     """
     return __SingletonTurtle().pendown()
 
+
 def penup():
     """Pull the pen up -- no drawing when moving.
 
@@ -516,6 +561,7 @@ def penup():
     """
     return __SingletonTurtle().penup()
 
+
 def pensize(width=None):
     """Set or return the line thickness.
 
@@ -536,6 +582,7 @@ def pensize(width=None):
     """
     return __SingletonTurtle().pensize(width=width)
 
+
 def begin_fill(width=None):
     """Called just before drawing a shape to be filled.
 
@@ -549,6 +596,7 @@ def begin_fill(width=None):
     """
     return __SingletonTurtle().begin_fill()
 
+
 def end_fill(width=None):
     """Fill the shape drawn after the call begin_fill().
 
@@ -562,6 +610,7 @@ def end_fill(width=None):
     """
     return __SingletonTurtle().end_fill()
 
+
 def isdown() -> bool:
     """Return True if pen is down, False if it's up.
 
@@ -577,6 +626,7 @@ def isdown() -> bool:
     """
     return __SingletonTurtle().isdown()
 
+
 def write(arg, move=False, align="left", font=("Arial", 8, "normal")):
     """Write text at the current turtle position.
 
@@ -598,6 +648,7 @@ def write(arg, move=False, align="left", font=("Arial", 8, "normal")):
     """
     return __SingletonTurtle().write(arg, move=move, align=align, font=font)
 
+
 def hideturtle():
     """Makes the turtle invisible.
 
@@ -614,6 +665,37 @@ def hideturtle():
     """
     return __SingletonTurtle().hideturtle()
 
+
+def speed(speed=None):
+    """ Return or set the turtle's speed.
+
+    Optional argument:
+    speed -- an integer in the range 0..10 or a speedstring (see below)
+
+    Set the turtle's speed to an integer value in the range 0 .. 10.
+    If no argument is given: return current speed.
+
+    If input is a number greater than 10 or smaller than 0.5,
+    speed is set to 0.
+    Speedstrings  are mapped to speedvalues in the following way:
+        'fastest' :  0
+        'fast'    :  10
+        'normal'  :  6
+        'slow'    :  3
+        'slowest' :  1
+    speeds from 1 to 10 enforce increasingly faster animation of
+    line drawing and turtle turning.
+
+    Attention:
+    speed = 0 : *no* animation takes place. forward/back makes turtle jump
+    and likewise left/right make the turtle turn instantly.
+
+    Example (for a Turtle instance named turtle):
+    >>> turtle.speed(3)
+    """
+    return __SingletonTurtle().speed()
+
+
 def showturtle():
     """Makes the turtle visible.
 
@@ -627,6 +709,7 @@ def showturtle():
     """
     return __SingletonTurtle().showturtle()
 
+
 def isvisible():
     """Return True if the Turtle is shown, False if it's hidden.
 
